==> nextcloud-18.0.4.tgz: nextcloud/apps/federation/l10n/lt_LT.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridėtas į patikimų serverių sąrašą",
    "Server is already in the list of trusted servers." : "Serveris jau yra patikimų serverių sąraše.",
    "No server to federate with found" : "Nerasta jokio serverio, su kuriuo jungtis į federaciją",
    "Could not add server" : "Nepavyko pridėti serverio",
    "Federation" : "Federacija",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federacija jums leidžia prisijungti prie kitų patikimų serverių, siekiant keistis naudotojo katalogu.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federacija leidžia jums prisijungti prie kitų patikimų serverių, siekiant keistis naudotojo katalogu. Pavyzdžiui, tai bus naudojama, kad būtų automatiškai užbaigti išoriniai federacinio bendrinimo naudotojų vardai.",
    "Trusted servers" : "Patikimi serveriai",
    "Add server automatically once a federated share was created successfully" : "Sėkmingai sukūrus federacinį viešinį, automatiškai pridėti serverį",
    "+ Add trusted server" : "+ Pridėti patikimą serverį",
    "Trusted server" : "Patikimas serveris",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-19.0.8.tgz: nextcloud/apps/federation/l10n/lt_LT.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Pridėtas į patikimų serverių sąrašą",
    "Server is already in the list of trusted servers." : "Serveris jau yra patikimų serverių sąraše.",
    "No server to federate with found" : "Nerasta jokio serverio, su kuriuo jungtis į federaciją",
    "Could not add server" : "Nepavyko pridėti serverio",
    "Federation" : "Federacija",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federacija jums leidžia prisijungti prie kitų patikimų serverių, siekiant keistis naudotojo katalogu.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federacija leidžia jums prisijungti prie kitų patikimų serverių, siekiant keistis naudotojo katalogu. Pavyzdžiui, tai bus naudojama, kad būtų automatiškai užbaigti išoriniai federacinio bendrinimo naudotojų vardai.",
    "Trusted servers" : "Patikimi serveriai",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Gederacijos paslauga suteikia galimybę prisijungti prie kitų patikimų serverių, kad būtų galima keistis naudotojų katalogu. Pavyzdžiui, tai bus naudojama, kad būtų automatiškai užbaigti išoriniai federacinio bendrinimo naudotojų vardai.",
    "Add server automatically once a federated share was created successfully" : "Sėkmingai sukūrus federacinį viešinį, automatiškai pridėti serverį",
    "+ Add trusted server" : "+ Pridėti patikimą serverį",
    "Trusted server" : "Patikimas serveris",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
